rm(list=ls())

library(sspir)
library(RColorBrewer)

source("successionmeasures.statespace4.R")

hoverflies <- read.delim(file="hoverflies.txt",header=TRUE,sep="\t")

reps <- 10 #reps <- 1000 for manuscript
maxit <- 500
savename <- "hoverflyfit.RData"
excludeunseen <- TRUE #exclude species that were never observed?
newfit <- TRUE #re-estimate? Otherwise load from savename

if(newfit==TRUE){
	if(excludeunseen){
		cs <- colSums(hoverflies)
		if(length(which(cs==0))>0) hoverflies <- hoverflies[,-(which(cs==0))]
	}

	nspp <- dim(hoverflies)[2]-1
	nyears <- dim(hoverflies)[1]

	#get rate of succession and mean growth rate between adjacent years
	sssuc <- getsucc(hoverflies[,1:nspp],reps,maxit)
        save.image(file=savename)
} else {
  load(savename)
  source("successionmeasures.statespace4.R")
}

par(mfrow=c(3,1))
par(mar=c(4,5.1,2,0.5))
par(mgp=c(2.5,1,0)) #axis title, labels, line

plotlograw(year=hoverflies$year,abundances=hoverflies[,1:nspp],yl=range(sssuc$xmean),panel.label="A") #log of abundances + 1 against time
plotrbar(year=hoverflies$year,sssuc=sssuc,panel.label="B") #rbar against time
plotsr(year=hoverflies$year,sssuc=sssuc,panel.label="C") #sr against time


